Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=ipam.netbox.natzkalabs.com +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type AvailablePrefix
- func (in *AvailablePrefix) DeepCopy() *AvailablePrefix
- func (in *AvailablePrefix) DeepCopyInto(out *AvailablePrefix)
- func (in *AvailablePrefix) DeepCopyObject() runtime.Object
- func (mg *AvailablePrefix) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *AvailablePrefix) GetConnectionDetailsMapping() map[string]string
- func (mg *AvailablePrefix) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *AvailablePrefix) GetID() string
- func (tr *AvailablePrefix) GetInitParameters() (map[string]any, error)
- func (mg *AvailablePrefix) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *AvailablePrefix) GetObservation() (map[string]any, error)
- func (tr *AvailablePrefix) GetParameters() (map[string]any, error)
- func (mg *AvailablePrefix) GetProviderConfigReference() *xpv1.Reference
- func (mg *AvailablePrefix) GetProviderReference() *xpv1.Reference
- func (mg *AvailablePrefix) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *AvailablePrefix) GetTerraformResourceType() string
- func (tr *AvailablePrefix) GetTerraformSchemaVersion() int
- func (mg *AvailablePrefix) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *AvailablePrefix) LateInitialize(attrs []byte) (bool, error)
- func (mg *AvailablePrefix) SetConditions(c ...xpv1.Condition)
- func (mg *AvailablePrefix) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *AvailablePrefix) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *AvailablePrefix) SetObservation(obs map[string]any) error
- func (tr *AvailablePrefix) SetParameters(params map[string]any) error
- func (mg *AvailablePrefix) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *AvailablePrefix) SetProviderReference(r *xpv1.Reference)
- func (mg *AvailablePrefix) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *AvailablePrefix) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type AvailablePrefixInitParameters
- type AvailablePrefixList
- type AvailablePrefixObservation
- type AvailablePrefixParameters
- type AvailablePrefixSpec
- type AvailablePrefixStatus
- type Prefix
- func (in *Prefix) DeepCopy() *Prefix
- func (in *Prefix) DeepCopyInto(out *Prefix)
- func (in *Prefix) DeepCopyObject() runtime.Object
- func (mg *Prefix) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Prefix) GetConnectionDetailsMapping() map[string]string
- func (mg *Prefix) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Prefix) GetID() string
- func (tr *Prefix) GetInitParameters() (map[string]any, error)
- func (mg *Prefix) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *Prefix) GetObservation() (map[string]any, error)
- func (tr *Prefix) GetParameters() (map[string]any, error)
- func (mg *Prefix) GetProviderConfigReference() *xpv1.Reference
- func (mg *Prefix) GetProviderReference() *xpv1.Reference
- func (mg *Prefix) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Prefix) GetTerraformResourceType() string
- func (tr *Prefix) GetTerraformSchemaVersion() int
- func (mg *Prefix) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Prefix) LateInitialize(attrs []byte) (bool, error)
- func (mg *Prefix) SetConditions(c ...xpv1.Condition)
- func (mg *Prefix) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *Prefix) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *Prefix) SetObservation(obs map[string]any) error
- func (tr *Prefix) SetParameters(params map[string]any) error
- func (mg *Prefix) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Prefix) SetProviderReference(r *xpv1.Reference)
- func (mg *Prefix) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Prefix) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type PrefixInitParameters
- type PrefixList
- type PrefixObservation
- type PrefixParameters
- type PrefixSpec
- type PrefixStatus
Constants ¶
const ( CRDGroup = "ipam.netbox.natzkalabs.com" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( AvailablePrefix_Kind = "AvailablePrefix" AvailablePrefix_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: AvailablePrefix_Kind}.String() AvailablePrefix_KindAPIVersion = AvailablePrefix_Kind + "." + CRDGroupVersion.String() AvailablePrefix_GroupVersionKind = CRDGroupVersion.WithKind(AvailablePrefix_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( Prefix_Kind = "Prefix" Prefix_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Prefix_Kind}.String() Prefix_KindAPIVersion = Prefix_Kind + "." + CRDGroupVersion.String() Prefix_GroupVersionKind = CRDGroupVersion.WithKind(Prefix_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type AvailablePrefix ¶
type AvailablePrefix struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.parentPrefixId) || has(self.initProvider.parentPrefixId)",message="parentPrefixId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.prefixLength) || has(self.initProvider.prefixLength)",message="prefixLength is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.status) || has(self.initProvider.status)",message="status is a required parameter"
Spec AvailablePrefixSpec `json:"spec"`
Status AvailablePrefixStatus `json:"status,omitempty"`
}
AvailablePrefix is the Schema for the AvailablePrefixs API. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,netbox}
func (*AvailablePrefix) DeepCopy ¶
func (in *AvailablePrefix) DeepCopy() *AvailablePrefix
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AvailablePrefix.
func (*AvailablePrefix) DeepCopyInto ¶
func (in *AvailablePrefix) DeepCopyInto(out *AvailablePrefix)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AvailablePrefix) DeepCopyObject ¶
func (in *AvailablePrefix) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*AvailablePrefix) GetCondition ¶
func (mg *AvailablePrefix) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this AvailablePrefix.
func (*AvailablePrefix) GetConnectionDetailsMapping ¶
func (tr *AvailablePrefix) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this AvailablePrefix
func (*AvailablePrefix) GetDeletionPolicy ¶
func (mg *AvailablePrefix) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this AvailablePrefix.
func (*AvailablePrefix) GetID ¶
func (tr *AvailablePrefix) GetID() string
GetID returns ID of underlying Terraform resource of this AvailablePrefix
func (*AvailablePrefix) GetInitParameters ¶
func (tr *AvailablePrefix) GetInitParameters() (map[string]any, error)
GetInitParameters of this AvailablePrefix
func (*AvailablePrefix) GetManagementPolicies ¶
func (mg *AvailablePrefix) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this AvailablePrefix.
func (*AvailablePrefix) GetObservation ¶
func (tr *AvailablePrefix) GetObservation() (map[string]any, error)
GetObservation of this AvailablePrefix
func (*AvailablePrefix) GetParameters ¶
func (tr *AvailablePrefix) GetParameters() (map[string]any, error)
GetParameters of this AvailablePrefix
func (*AvailablePrefix) GetProviderConfigReference ¶
func (mg *AvailablePrefix) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this AvailablePrefix.
func (*AvailablePrefix) GetProviderReference ¶
func (mg *AvailablePrefix) GetProviderReference() *xpv1.Reference
GetProviderReference of this AvailablePrefix. Deprecated: Use GetProviderConfigReference.
func (*AvailablePrefix) GetPublishConnectionDetailsTo ¶
func (mg *AvailablePrefix) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this AvailablePrefix.
func (*AvailablePrefix) GetTerraformResourceType ¶
func (mg *AvailablePrefix) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this AvailablePrefix
func (*AvailablePrefix) GetTerraformSchemaVersion ¶
func (tr *AvailablePrefix) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*AvailablePrefix) GetWriteConnectionSecretToReference ¶
func (mg *AvailablePrefix) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this AvailablePrefix.
func (*AvailablePrefix) LateInitialize ¶
func (tr *AvailablePrefix) LateInitialize(attrs []byte) (bool, error)
LateInitialize this AvailablePrefix using its observed tfState. returns True if there are any spec changes for the resource.
func (*AvailablePrefix) SetConditions ¶
func (mg *AvailablePrefix) SetConditions(c ...xpv1.Condition)
SetConditions of this AvailablePrefix.
func (*AvailablePrefix) SetDeletionPolicy ¶
func (mg *AvailablePrefix) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this AvailablePrefix.
func (*AvailablePrefix) SetManagementPolicies ¶
func (mg *AvailablePrefix) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this AvailablePrefix.
func (*AvailablePrefix) SetObservation ¶
func (tr *AvailablePrefix) SetObservation(obs map[string]any) error
SetObservation for this AvailablePrefix
func (*AvailablePrefix) SetParameters ¶
func (tr *AvailablePrefix) SetParameters(params map[string]any) error
SetParameters for this AvailablePrefix
func (*AvailablePrefix) SetProviderConfigReference ¶
func (mg *AvailablePrefix) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this AvailablePrefix.
func (*AvailablePrefix) SetProviderReference ¶
func (mg *AvailablePrefix) SetProviderReference(r *xpv1.Reference)
SetProviderReference of this AvailablePrefix. Deprecated: Use SetProviderConfigReference.
func (*AvailablePrefix) SetPublishConnectionDetailsTo ¶
func (mg *AvailablePrefix) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this AvailablePrefix.
func (*AvailablePrefix) SetWriteConnectionSecretToReference ¶
func (mg *AvailablePrefix) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this AvailablePrefix.
type AvailablePrefixInitParameters ¶
type AvailablePrefixInitParameters struct {
// (String)
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// (Boolean)
IsPool *bool `json:"isPool,omitempty" tf:"is_pool,omitempty"`
// (Boolean)
MarkUtilized *bool `json:"markUtilized,omitempty" tf:"mark_utilized,omitempty"`
// (Number)
ParentPrefixID *float64 `json:"parentPrefixId,omitempty" tf:"parent_prefix_id,omitempty"`
// (Number)
PrefixLength *float64 `json:"prefixLength,omitempty" tf:"prefix_length,omitempty"`
// (Number)
RoleID *float64 `json:"roleId,omitempty" tf:"role_id,omitempty"`
// (Number)
SiteID *float64 `json:"siteId,omitempty" tf:"site_id,omitempty"`
// (String) Valid values are active, container, reserved and deprecated.
// Valid values are `active`, `container`, `reserved` and `deprecated`.
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// (Set of String)
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
// (Number)
TenantID *float64 `json:"tenantId,omitempty" tf:"tenant_id,omitempty"`
// (Number)
VlanID *float64 `json:"vlanId,omitempty" tf:"vlan_id,omitempty"`
// (Number)
VrfID *float64 `json:"vrfId,omitempty" tf:"vrf_id,omitempty"`
}
func (*AvailablePrefixInitParameters) DeepCopy ¶
func (in *AvailablePrefixInitParameters) DeepCopy() *AvailablePrefixInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AvailablePrefixInitParameters.
func (*AvailablePrefixInitParameters) DeepCopyInto ¶
func (in *AvailablePrefixInitParameters) DeepCopyInto(out *AvailablePrefixInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AvailablePrefixList ¶
type AvailablePrefixList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []AvailablePrefix `json:"items"`
}
AvailablePrefixList contains a list of AvailablePrefixs
func (*AvailablePrefixList) DeepCopy ¶
func (in *AvailablePrefixList) DeepCopy() *AvailablePrefixList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AvailablePrefixList.
func (*AvailablePrefixList) DeepCopyInto ¶
func (in *AvailablePrefixList) DeepCopyInto(out *AvailablePrefixList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AvailablePrefixList) DeepCopyObject ¶
func (in *AvailablePrefixList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*AvailablePrefixList) GetItems ¶
func (l *AvailablePrefixList) GetItems() []resource.Managed
GetItems of this AvailablePrefixList.
type AvailablePrefixObservation ¶
type AvailablePrefixObservation struct {
// (String)
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// (String) The ID of this resource.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// (Boolean)
IsPool *bool `json:"isPool,omitempty" tf:"is_pool,omitempty"`
// (Boolean)
MarkUtilized *bool `json:"markUtilized,omitempty" tf:"mark_utilized,omitempty"`
// (Number)
ParentPrefixID *float64 `json:"parentPrefixId,omitempty" tf:"parent_prefix_id,omitempty"`
// (String)
Prefix *string `json:"prefix,omitempty" tf:"prefix,omitempty"`
// (Number)
PrefixLength *float64 `json:"prefixLength,omitempty" tf:"prefix_length,omitempty"`
// (Number)
RoleID *float64 `json:"roleId,omitempty" tf:"role_id,omitempty"`
// (Number)
SiteID *float64 `json:"siteId,omitempty" tf:"site_id,omitempty"`
// (String) Valid values are active, container, reserved and deprecated.
// Valid values are `active`, `container`, `reserved` and `deprecated`.
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// (Set of String)
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
// (Number)
TenantID *float64 `json:"tenantId,omitempty" tf:"tenant_id,omitempty"`
// (Number)
VlanID *float64 `json:"vlanId,omitempty" tf:"vlan_id,omitempty"`
// (Number)
VrfID *float64 `json:"vrfId,omitempty" tf:"vrf_id,omitempty"`
}
func (*AvailablePrefixObservation) DeepCopy ¶
func (in *AvailablePrefixObservation) DeepCopy() *AvailablePrefixObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AvailablePrefixObservation.
func (*AvailablePrefixObservation) DeepCopyInto ¶
func (in *AvailablePrefixObservation) DeepCopyInto(out *AvailablePrefixObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AvailablePrefixParameters ¶
type AvailablePrefixParameters struct {
// (String)
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// (Boolean)
// +kubebuilder:validation:Optional
IsPool *bool `json:"isPool,omitempty" tf:"is_pool,omitempty"`
// (Boolean)
// +kubebuilder:validation:Optional
MarkUtilized *bool `json:"markUtilized,omitempty" tf:"mark_utilized,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
ParentPrefixID *float64 `json:"parentPrefixId,omitempty" tf:"parent_prefix_id,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
PrefixLength *float64 `json:"prefixLength,omitempty" tf:"prefix_length,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
RoleID *float64 `json:"roleId,omitempty" tf:"role_id,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
SiteID *float64 `json:"siteId,omitempty" tf:"site_id,omitempty"`
// (String) Valid values are active, container, reserved and deprecated.
// Valid values are `active`, `container`, `reserved` and `deprecated`.
// +kubebuilder:validation:Optional
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// (Set of String)
// +kubebuilder:validation:Optional
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
TenantID *float64 `json:"tenantId,omitempty" tf:"tenant_id,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
VlanID *float64 `json:"vlanId,omitempty" tf:"vlan_id,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
VrfID *float64 `json:"vrfId,omitempty" tf:"vrf_id,omitempty"`
}
func (*AvailablePrefixParameters) DeepCopy ¶
func (in *AvailablePrefixParameters) DeepCopy() *AvailablePrefixParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AvailablePrefixParameters.
func (*AvailablePrefixParameters) DeepCopyInto ¶
func (in *AvailablePrefixParameters) DeepCopyInto(out *AvailablePrefixParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AvailablePrefixSpec ¶
type AvailablePrefixSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider AvailablePrefixParameters `json:"forProvider"`
// THIS IS AN ALPHA FIELD. Do not use it in production. It is not honored
// unless the relevant Crossplane feature flag is enabled, and may be
// changed or removed without notice.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider AvailablePrefixInitParameters `json:"initProvider,omitempty"`
}
AvailablePrefixSpec defines the desired state of AvailablePrefix
func (*AvailablePrefixSpec) DeepCopy ¶
func (in *AvailablePrefixSpec) DeepCopy() *AvailablePrefixSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AvailablePrefixSpec.
func (*AvailablePrefixSpec) DeepCopyInto ¶
func (in *AvailablePrefixSpec) DeepCopyInto(out *AvailablePrefixSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AvailablePrefixStatus ¶
type AvailablePrefixStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider AvailablePrefixObservation `json:"atProvider,omitempty"`
}
AvailablePrefixStatus defines the observed state of AvailablePrefix.
func (*AvailablePrefixStatus) DeepCopy ¶
func (in *AvailablePrefixStatus) DeepCopy() *AvailablePrefixStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AvailablePrefixStatus.
func (*AvailablePrefixStatus) DeepCopyInto ¶
func (in *AvailablePrefixStatus) DeepCopyInto(out *AvailablePrefixStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Prefix ¶
type Prefix struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.prefix) || has(self.initProvider.prefix)",message="prefix is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.status) || has(self.initProvider.status)",message="status is a required parameter"
Spec PrefixSpec `json:"spec"`
Status PrefixStatus `json:"status,omitempty"`
}
Prefix is the Schema for the Prefixs API. From the official documentation https://docs.netbox.dev/en/stable/features/ipam/#prefixes: A prefix is an IPv4 or IPv6 network and mask expressed in CIDR notation (e.g. 192.0.2.0/24). A prefix entails only the "network portion" of an IP address: All bits in the address not covered by the mask must be zero. (In other words, a prefix cannot be a specific IP address.) Prefixes are automatically organized by their parent aggregates. Additionally, each prefix can be assigned to a particular site and virtual routing and forwarding instance (VRF). Each VRF represents a separate IP space or routing table. All prefixes not assigned to a VRF are considered to be in the "global" table. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,netbox}
func (*Prefix) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Prefix.
func (*Prefix) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Prefix) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Prefix) GetCondition ¶
func (mg *Prefix) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Prefix.
func (*Prefix) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this Prefix
func (*Prefix) GetDeletionPolicy ¶
func (mg *Prefix) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Prefix.
func (*Prefix) GetInitParameters ¶
GetInitParameters of this Prefix
func (*Prefix) GetManagementPolicies ¶
func (mg *Prefix) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this Prefix.
func (*Prefix) GetObservation ¶
GetObservation of this Prefix
func (*Prefix) GetParameters ¶
GetParameters of this Prefix
func (*Prefix) GetProviderConfigReference ¶
GetProviderConfigReference of this Prefix.
func (*Prefix) GetProviderReference ¶
GetProviderReference of this Prefix. Deprecated: Use GetProviderConfigReference.
func (*Prefix) GetPublishConnectionDetailsTo ¶
func (mg *Prefix) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Prefix.
func (*Prefix) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this Prefix
func (*Prefix) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Prefix) GetWriteConnectionSecretToReference ¶
func (mg *Prefix) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Prefix.
func (*Prefix) LateInitialize ¶
LateInitialize this Prefix using its observed tfState. returns True if there are any spec changes for the resource.
func (*Prefix) SetConditions ¶
SetConditions of this Prefix.
func (*Prefix) SetDeletionPolicy ¶
func (mg *Prefix) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Prefix.
func (*Prefix) SetManagementPolicies ¶
func (mg *Prefix) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this Prefix.
func (*Prefix) SetObservation ¶
SetObservation for this Prefix
func (*Prefix) SetParameters ¶
SetParameters for this Prefix
func (*Prefix) SetProviderConfigReference ¶
SetProviderConfigReference of this Prefix.
func (*Prefix) SetProviderReference ¶
SetProviderReference of this Prefix. Deprecated: Use SetProviderConfigReference.
func (*Prefix) SetPublishConnectionDetailsTo ¶
func (mg *Prefix) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Prefix.
func (*Prefix) SetWriteConnectionSecretToReference ¶
func (mg *Prefix) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Prefix.
type PrefixInitParameters ¶
type PrefixInitParameters struct {
// (String)
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// (Boolean)
IsPool *bool `json:"isPool,omitempty" tf:"is_pool,omitempty"`
// (Boolean)
MarkUtilized *bool `json:"markUtilized,omitempty" tf:"mark_utilized,omitempty"`
// (String)
Prefix *string `json:"prefix,omitempty" tf:"prefix,omitempty"`
// (Number)
RoleID *float64 `json:"roleId,omitempty" tf:"role_id,omitempty"`
// (Number)
SiteID *float64 `json:"siteId,omitempty" tf:"site_id,omitempty"`
// (String) Valid values are active, container, reserved and deprecated.
// Valid values are `active`, `container`, `reserved` and `deprecated`.
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// (Set of String)
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
// (Number)
TenantID *float64 `json:"tenantId,omitempty" tf:"tenant_id,omitempty"`
// (Number)
VlanID *float64 `json:"vlanId,omitempty" tf:"vlan_id,omitempty"`
// (Number)
VrfID *float64 `json:"vrfId,omitempty" tf:"vrf_id,omitempty"`
}
func (*PrefixInitParameters) DeepCopy ¶
func (in *PrefixInitParameters) DeepCopy() *PrefixInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrefixInitParameters.
func (*PrefixInitParameters) DeepCopyInto ¶
func (in *PrefixInitParameters) DeepCopyInto(out *PrefixInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrefixList ¶
type PrefixList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Prefix `json:"items"`
}
PrefixList contains a list of Prefixs
func (*PrefixList) DeepCopy ¶
func (in *PrefixList) DeepCopy() *PrefixList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrefixList.
func (*PrefixList) DeepCopyInto ¶
func (in *PrefixList) DeepCopyInto(out *PrefixList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PrefixList) DeepCopyObject ¶
func (in *PrefixList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PrefixList) GetItems ¶
func (l *PrefixList) GetItems() []resource.Managed
GetItems of this PrefixList.
type PrefixObservation ¶
type PrefixObservation struct {
// (String)
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// (String) The ID of this resource.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// (Boolean)
IsPool *bool `json:"isPool,omitempty" tf:"is_pool,omitempty"`
// (Boolean)
MarkUtilized *bool `json:"markUtilized,omitempty" tf:"mark_utilized,omitempty"`
// (String)
Prefix *string `json:"prefix,omitempty" tf:"prefix,omitempty"`
// (Number)
RoleID *float64 `json:"roleId,omitempty" tf:"role_id,omitempty"`
// (Number)
SiteID *float64 `json:"siteId,omitempty" tf:"site_id,omitempty"`
// (String) Valid values are active, container, reserved and deprecated.
// Valid values are `active`, `container`, `reserved` and `deprecated`.
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// (Set of String)
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
// (Number)
TenantID *float64 `json:"tenantId,omitempty" tf:"tenant_id,omitempty"`
// (Number)
VlanID *float64 `json:"vlanId,omitempty" tf:"vlan_id,omitempty"`
// (Number)
VrfID *float64 `json:"vrfId,omitempty" tf:"vrf_id,omitempty"`
}
func (*PrefixObservation) DeepCopy ¶
func (in *PrefixObservation) DeepCopy() *PrefixObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrefixObservation.
func (*PrefixObservation) DeepCopyInto ¶
func (in *PrefixObservation) DeepCopyInto(out *PrefixObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrefixParameters ¶
type PrefixParameters struct {
// (String)
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// (Boolean)
// +kubebuilder:validation:Optional
IsPool *bool `json:"isPool,omitempty" tf:"is_pool,omitempty"`
// (Boolean)
// +kubebuilder:validation:Optional
MarkUtilized *bool `json:"markUtilized,omitempty" tf:"mark_utilized,omitempty"`
// (String)
// +kubebuilder:validation:Optional
Prefix *string `json:"prefix,omitempty" tf:"prefix,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
RoleID *float64 `json:"roleId,omitempty" tf:"role_id,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
SiteID *float64 `json:"siteId,omitempty" tf:"site_id,omitempty"`
// (String) Valid values are active, container, reserved and deprecated.
// Valid values are `active`, `container`, `reserved` and `deprecated`.
// +kubebuilder:validation:Optional
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// (Set of String)
// +kubebuilder:validation:Optional
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
TenantID *float64 `json:"tenantId,omitempty" tf:"tenant_id,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
VlanID *float64 `json:"vlanId,omitempty" tf:"vlan_id,omitempty"`
// (Number)
// +kubebuilder:validation:Optional
VrfID *float64 `json:"vrfId,omitempty" tf:"vrf_id,omitempty"`
}
func (*PrefixParameters) DeepCopy ¶
func (in *PrefixParameters) DeepCopy() *PrefixParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrefixParameters.
func (*PrefixParameters) DeepCopyInto ¶
func (in *PrefixParameters) DeepCopyInto(out *PrefixParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrefixSpec ¶
type PrefixSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider PrefixParameters `json:"forProvider"`
// THIS IS AN ALPHA FIELD. Do not use it in production. It is not honored
// unless the relevant Crossplane feature flag is enabled, and may be
// changed or removed without notice.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider PrefixInitParameters `json:"initProvider,omitempty"`
}
PrefixSpec defines the desired state of Prefix
func (*PrefixSpec) DeepCopy ¶
func (in *PrefixSpec) DeepCopy() *PrefixSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrefixSpec.
func (*PrefixSpec) DeepCopyInto ¶
func (in *PrefixSpec) DeepCopyInto(out *PrefixSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrefixStatus ¶
type PrefixStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider PrefixObservation `json:"atProvider,omitempty"`
}
PrefixStatus defines the observed state of Prefix.
func (*PrefixStatus) DeepCopy ¶
func (in *PrefixStatus) DeepCopy() *PrefixStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrefixStatus.
func (*PrefixStatus) DeepCopyInto ¶
func (in *PrefixStatus) DeepCopyInto(out *PrefixStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.